==> aws-java-sdk-codedeploy-1.11.25-sources.jar: com/amazonaws/services/codedeploy/waiters/AmazonCodeDeployWaiters.java <==
/*
 * Copyright 2011-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not
 * use this file except in compliance with the License. A copy of the License is
 * located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.codedeploy.waiters;

import com.amazonaws.annotation.SdkInternalApi;
import com.amazonaws.services.codedeploy.AmazonCodeDeploy;
import com.amazonaws.services.codedeploy.model.*;
import com.amazonaws.waiters.*;

import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

public class AmazonCodeDeployWaiters {

    /**
     * Represents the service client
     */
    private final AmazonCodeDeploy client;

    private final ExecutorService executorService = Executors
            .newFixedThreadPool(50);

    /**
     * Constructs a new AmazonCodeDeployWaiters with the given client
     * 
     * @param client
     *        Service client
     */
    @SdkInternalApi
    public AmazonCodeDeployWaiters(AmazonCodeDeploy client) {
        this.client = client;
    }

    /**
     * Builds a DeploymentSuccessful waiter by using custom parameters
     * waiterParameters and other parameters defined in the waiters
     * specification, and then polls until it determines whether the resource
     * entered the desired state or not, where polling criteria is bound by
     * either default polling strategy or custom polling strategy.
     */
    public Waiter deploymentSuccessful() {

        return new WaiterBuilder<GetDeploymentRequest, GetDeploymentResult>()
                .withSdkFunction(new GetDeploymentFunction(client))
                .withAcceptors(new DeploymentSuccessful.IsSucceededMatcher(),
                        new DeploymentSuccessful.IsFailedMatcher(),
                        new DeploymentSuccessful.IsStoppedMatcher())
                .withDefaultPollingStrategy(
                        new PollingStrategy(new MaxAttemptsRetryStrategy(120),
                                new FixedDelayStrategy(15)))
                .withExecutorService(executorService).build();
    }

}

==> aws-java-sdk-codedeploy-1.11.30-sources.jar: com/amazonaws/services/codedeploy/waiters/AmazonCodeDeployWaiters.java <==
/*
 * Copyright 2011-2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"). You may not
 * use this file except in compliance with the License. A copy of the License is
 * located at
 * 
 * http://aws.amazon.com/apache2.0
 * 
 * or in the "license" file accompanying this file. This file is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.codedeploy.waiters;

import com.amazonaws.annotation.SdkInternalApi;
import com.amazonaws.services.codedeploy.AmazonCodeDeploy;
import com.amazonaws.services.codedeploy.model.*;
import com.amazonaws.waiters.*;

import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;

public class AmazonCodeDeployWaiters {

    /**
     * Represents the service client
     */
    private final AmazonCodeDeploy client;

    private final ExecutorService executorService = Executors
            .newFixedThreadPool(50);

    /**
     * Constructs a new AmazonCodeDeployWaiters with the given client
     * 
     * @param client
     *        Service client
     */
    @SdkInternalApi
    public AmazonCodeDeployWaiters(AmazonCodeDeploy client) {
        this.client = client;
    }

    /**
     * Builds a DeploymentSuccessful waiter by using custom parameters
     * waiterParameters and other parameters defined in the waiters
     * specification, and then polls until it determines whether the resource
     * entered the desired state or not, where polling criteria is bound by
     * either default polling strategy or custom polling strategy.
     */
    public Waiter<GetDeploymentRequest> deploymentSuccessful() {

        return new WaiterBuilder<GetDeploymentRequest, GetDeploymentResult>()
                .withSdkFunction(new GetDeploymentFunction(client))
                .withAcceptors(new DeploymentSuccessful.IsSucceededMatcher(),
                        new DeploymentSuccessful.IsFailedMatcher(),
                        new DeploymentSuccessful.IsStoppedMatcher())
                .withDefaultPollingStrategy(
                        new PollingStrategy(new MaxAttemptsRetryStrategy(120),
                                new FixedDelayStrategy(15)))
                .withExecutorService(executorService).build();
    }

}
